@@ -6,7 +6,7 @@ Toadfarm - One Mojolicious app to rule them all
 
 =head1 VERSION
 
-0.58
+0.59
 
 =head1 DESCRIPTION
 
@@ -159,7 +159,7 @@ use File::Spec;
 use File::Which;
 use constant DEBUG => $ENV{TOADFARM_DEBUG} ? 1 : 0;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 BEGIN {
   $ENV{TOADFARM_ACTION} //= (@ARGV and $ARGV[0] =~ /^(reload|start|stop)$/) ? $1 : 'load';
@@ -310,8 +310,8 @@ sub _mount_apps {
 
     if (@over) {
       $self->log->info("Mounting $path with conditions");
-      unshift @over, "sub { my \$h = \$_[1]->req->headers;\n";
-      push @over, "\$_[1]->req->url->base(Mojo::URL->new('$request_base'));" if $request_base;
+      unshift @over, "sub { my \$h = \$_[1]->req->headers;\nlocal \$1;";
+      push @over, "\$_[1]->req->url->base(Mojo::URL->new(\$1 || '$request_base'));" if $request_base;
       push @over, "return 1; }";
       $routes->add_condition("toadfarm_condition_$self->{mounted}", => eval "@over" || die "@over: $@");
       $routes->route($mount_point || '/')->detour(app => $app)->over("toadfarm_condition_$self->{mounted}");
@@ -364,11 +364,12 @@ sub _run_as {
   for my $p (File::Spec->path) {
     $sudo[0] = File::Spec->catfile($p, 'sudo');
     next unless -x $sudo[0];
-    push @sudo, '-n', -u => "#$uid", $^X;
+    push @sudo, qw( -H -n -u ), "#$uid";
     last;
   }
 
   die "Cannot change to uid=$uid: 'sudo' was not found.\n" unless @sudo > 1;
+  push @sudo, $^X;
   push @sudo, -I => $INC[0] if $ENV{TOADFARM_ACTION} eq 'test';
   push @sudo, File::Spec->rel2abs($0), @ARGV;
   warn "[Toadfarm] system @sudo\n" if DEBUG;
@@ -420,7 +421,8 @@ sub _skip_if {
     return;
   }
   elsif (ref $value eq 'Regexp') {
-    return sprintf "return 0 unless +($format || '') =~ /%s/;", $k, $value;
+    $value =~ s,(?<!\\)/,\\/,g;
+    return sprintf "return 0 unless +($format || '') =~ /(%s)/;", $k, $value;
   }
   else {
     return sprintf "return 0 unless +($format || '') eq '%s';", $k, $value;
